@@ -1,5 +1,5 @@
 package Form::Factory::Feature::Control::Trim;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 
 use Moose;
@@ -10,13 +10,15 @@ with qw(
     Form::Factory::Feature::Role::Control
 );
 
+use Carp ();
+
 =head1 NAME
 
 Form::Factory::Feature::Control::Trim - Trims whitespace from a control value
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -44,7 +46,7 @@ sub check_control {
 
     return if $control->does('Form::Factory::Control::Role::ScalarValue');
 
-    die "the trim feature only works on scalar values, not $control";
+    Carp::croak("the trim feature only works on scalar values, not $control");
 }
 
 =head2 clean
