@@ -1,9 +1,10 @@
 package Form::Factory::Interface;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 
 use Moose::Role;
 
+use Carp ();
 use Form::Factory::Stasher::Memory;
 
 requires qw( render_control consume_control );
@@ -14,12 +15,12 @@ Form::Factory::Interface - Role for form interface implementations
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
   package MyApp::Interface::MyUI;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 
   use Moose;
@@ -39,7 +40,7 @@ our $VERSION = '0.011';
   }
 
   package Form::Factory::Interface::Custom::MyUI;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 
   sub register_implementation { 'MyApp::Interface::MyUI' }
@@ -84,7 +85,7 @@ sub new_action {
     my ($self, $class_name, $args) = @_;
 
     Class::MOP::load_class($class_name)
-        or die "cannot load $class_name: $@";
+        or Carp::croak("cannot load $class_name: $@");
 
     return $class_name->new( %$args, form_interface => $self );
 }
